pub struct ServiceWorkerManager {
registrations: HashMap<ServoUrl, ServiceWorkerRegistration>,
_constellation_sender: GenericSender<SWManagerMsg>,
own_sender: GenericSender<ServiceWorkerMsg>,
own_port: RoutedReceiver<ServiceWorkerMsg>,
resource_receiver: Receiver<CustomResponseMediator>,
font_context: Arc<FontContext>,
}Expand description
A structure managing all registrations and workers for a given origin.
Fields
registrations: HashMap<ServoUrl, ServiceWorkerRegistration>_constellation_sender: GenericSender<SWManagerMsg>own_sender: GenericSender<ServiceWorkerMsg>own_port: RoutedReceiver<ServiceWorkerMsg>resource_receiver: Receiver<CustomResponseMediator>font_context: Arc<FontContext>A shared FontContext to use for all service workers spawned by this ServiceWorkerManager.
Implementations
Sourceimpl ServiceWorkerManager
impl ServiceWorkerManager
fn new( own_sender: GenericSender<ServiceWorkerMsg>, from_constellation_receiver: RoutedReceiver<ServiceWorkerMsg>, resource_port: Receiver<CustomResponseMediator>, constellation_sender: GenericSender<SWManagerMsg>, font_context: Arc<FontContext>, ) -> ServiceWorkerManager
pub(crate) fn get_matching_scope(&self, load_url: &ServoUrl) -> Option<ServoUrl>
fn handle_message(&mut self)
fn handle_message_from_resource( &mut self, mediator: CustomResponseMediator, ) -> bool
fn receive_message(&mut self) -> ReceiveResult<Message>
fn handle_message_from_constellation(&mut self, msg: ServiceWorkerMsg) -> bool
Sourcefn handle_register_job(&mut self, job: Job)
fn handle_register_job(&mut self, job: Job)
Sourcefn handle_update_job(&mut self, job: Job)
fn handle_update_job(&mut self, job: Job)